@@ -4,6 +4,8 @@
 Draupnir : Ancestral protein sequence reconstruction using a tree-structured Ornstein-Uhlenbeck variational autoencoder
 =======================
 """
+import sys
+#sys.path.append("./draupnir/src/draupnir")
 import draupnir.utils as DraupnirUtils
 import warnings
 from collections import namedtuple
@@ -24,14 +26,11 @@ def available_datasets(print_dict = False):
                 "simulations_PIGBOS_1": "PIGBOS_seq",# EvolveAGene4 PIGBOS simulation #300 leaves
                 "simulations_insulin_2": "Insulin_seq",# EvolveAGene4 Insulin simulation #400 leaves
                 "simulations_src_sh3_2":"SRC_SH3",# EvolveAGene4 SRC SH3 domain simulation 2 #800 leaves
-                "simulations_jj_1": "jj1",
-                "simulations_jj_2": "jj2",
                 "benchmark_randall_original_naming": None,# uses the original tree and it's original node naming
                 "SH3_pf00018_larger_than_30aa":  None,# SRC kinases domain SH3 ---> Leaves and angles testing
                 "Coral_Faviina":  None,  # Faviina clade from coral sequences # 35 leaves
                 "Coral_all": None,# All Coral sequences (includes Faviina clade and additional sequences) #71 leaves
                 "PF00400": None, # 125 real sequences
-                "PF00400_beta":None,#TEST DATA
                 "aminopeptidase":  None, #another real sequences example
                 "PF00096": None} #another real sequences example
     if print_dict:
@@ -46,24 +45,21 @@ def available_datasets(print_dict = False):
                 "simulations_insulin_2": "400 leaves Simulation Insulin Growth Factor",
                 "simulations_calcitonin_1": "50 leaves Simulation Calcitonin peptide",
                 "simulations_PIGBOS_1": "300 leaves parser.add_argument('-use-cuda', type=str2bool, nargs='?',const=True, default=True, help='Use GPU')simulation PIGB Opposite Strand regulator",
-                "simulations_jj_1": "jj1",
-                "simulations_jj_2": "jj2",
                 "Coral_Faviina":"Coral fluorescent proteins (CFP) Faviina clade",  # Faviina clade from coral sequences
                 "Coral_all":"Coral fluorescent proteins (CFP) clade",  # All Coral sequences (includes Faviina clade and additional sequences)
                 "PF00400":"WD40 125 sequences",
-                "PF00400_beta": "WD40 125 sequences", #TODO:Remove
                 "aminopeptidase":"Amino Peptidase",
                 "PF00096":"PF00096 protein kinases"}
     return datasets,datasets_full_names
-def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_file=None,tree_file=None,alignment_file=None):
+def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=None,tree_file=None,alignment_file=None):
     """In:
     :param str name: Dataset name
     :param bool use_custom: True (uses a custom dataset, located in datasets/custom/"folder_name" ) or False (uses a Draupnir default dataset (used in the publication))
     :param str script_dir: Working directory of Draupnir #TODO: remove
     :param bool build: Activates the construction of the dataset, might take a while if it requires to build tree, so it's recommended to use the pre-saved files
-    :param str or None fasta_file: Path to NOT aligned sequences
-    :param str or None tree_file: Path to Newick tree, format 1 in ete3
-    :param str or None alignment_file: Path to pre-aligned sequences
+    :param str fasta_file: Path to NOT aligned sequences
+    :param str tree_file: Path to Newick tree, format 1 in ete3
+    :param str alignment_file: Path to pre-aligned sequences
     :returns namedtuple build_config:
         :str alignment-file:
         :bool use_ancestral: True (patristic_matrix_train = patristic_matrix_full (leaves + ancestors)), False (patristic_matrix_train = patristic_matrix) otherwise we remove the ancestral nodes from patristic_matrix_train. Necessary for some datasets
@@ -74,12 +70,8 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
         :bool leaves_testing: True (uses all the leaf's evolutionary distances for training, it only observes (n-n_test) leafsequences. USE WITH n_test), False (uses all the leaf's evolutionary distances for training
                             and observes all the leaf sequences. Use with datasets without ancestors for testing, only generate sequences).
         """
-    BuildConfig = namedtuple('BuildConfig',['alignment_file','use_ancestral','n_test','build_graph',"aa_prob","triTSNE","leaves_testing","script_dir","no_testing"],module="build_config") #__name__ + ".namespace"
-    SettingsConfig = namedtuple("SettingsConfig", ["one_hot_encoding", "model_design", "aligned_seq","data_folder","full_name","tree_file"],module="settings_config")
-    if args.one_hot_encoded:
-        warnings.warn("Draupnir was constructed to be used with integers for Categorical likelihood,not OneHotCategorical. And blosum-encoding for the guide. You can build"
-                      "the one-hot-encoded dataset for other purposes")
-
+    BuildConfig = namedtuple('BuildConfig',['alignment_file','use_ancestral','n_test','build_graph',"aa_prob","triTSNE","leaves_testing","script_dir","no_testing"])
+    SettingsConfig = namedtuple("SettingsConfig", ["one_hot_encoding", "model_design", "aligned_seq","data_folder","full_name","tree_file"])
     #script_dir = os.path.dirname(os.path.abspath(__file__))
     if not use_custom:
         warnings.warn("You have selected a pre-defined dataset, if not present, it will be downloaded. Otherwise set use_custom to True")
@@ -107,11 +99,9 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                 "simulations_src_sh3_3":"https://drive.google.com/drive/folders/13xLOqW2ldRNm8OeU-bnp9DPEqU1d31Wy?usp=sharing"
 
             }
-        #download=False #TODO: Remove
         if os.path.isdir(dir_name):
             if not os.listdir(dir_name):
                 print("Directory is empty")
-                #if download:
                 os.remove(dir_name)
                 print("Data directory is missing. Downloading, this might take a while. If you see an error like \n"
                       " 'Cannot retrieve the public link of the file. You may need to change the permission to <Anyone with the link>, or have had many accesses', \n"
@@ -120,8 +110,6 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                     dict_urls[name]))
                 gdown.download_folder(dict_urls[name], output='{}/{}'.format(storage_folder, name), quiet=True,
                                       use_cookies=False, remaining_ok=True)
-                # else:
-                #     pass
 
 
             else:
@@ -130,30 +118,20 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
             print("Data directory is missing. Downloading, this might take a while. If you see an error like \n"
                   " 'Cannot retrieve the public link of the file. You may need to change the permission to <Anyone with the link>, or have had many accesses', \n"
                   "just wait, too many requests have been made to the google drive folder \n"
-                  "Otherwise just download the data sets MANUALLY from the google drive urls : \n {}".format(dict_urls[name]))
+                  "Otherwise just download the data sets manually from the google drive urls : \n {}".format(dict_urls[name]))
             gdown.download_folder(dict_urls[name], output='{}/{}'.format(storage_folder,name),quiet=True, use_cookies=False,remaining_ok=True)
 
+
+
         # Highlight: Simulation datasets, Simulations might produce stop codons---Use probabilities == 21
         if name.startswith("simulations"):
-            # leaves_prot = "{}/{}/jj1_True_Pep_alignment.FASTA".format(storage_folder,name)
-            # internal_prot = "{}/{}/jj1_pep_Internal_Nodes_True_alignment.FASTA".format(storage_folder,name)
-            # DraupnirUtils.remove_stop_codons(leaves_prot,is_prot=True)
-            # DraupnirUtils.remove_stop_codons(internal_prot,is_prot=True)
-            # exit()
+            # DraupnirUtils.Remove_Stop_Codons("Datasets_Simulations/{}/Dataset{}/{}.txt".format(simulation_folder,dataset_number,root_sequence_name))
             alignment_file = "{}/{}/{}_True_Pep_alignment.FASTA".format(storage_folder,name,root_sequence_name)
             tree_file = "{}/{}/{}_True_Rooted_tree_node_labels.tre".format(storage_folder,name,root_sequence_name)
-            build_config = BuildConfig(alignment_file=alignment_file,
-                                       use_ancestral=True,
-                                       n_test=0,
-                                       build_graph=True,
-                                       aa_prob=21,
-                                       triTSNE=False,
-                                       leaves_testing=False,
-                                       script_dir=script_dir,
-                                       no_testing=False)
+            build_config = BuildConfig(alignment_file=alignment_file, use_ancestral=True, n_test=0, build_graph=True,aa_prob=21,triTSNE=False,leaves_testing=False,script_dir=script_dir,no_testing=False)
             if build:
                 DraupnirUtils.create_dataset(name,
-                               one_hot_encoding=args.one_hot_encoded,
+                               one_hot_encoding=False,
                                tree_file= tree_file,
                                alignment_file="{}/{}/{}_True_Pep_alignment.FASTA".format(storage_folder,name,root_sequence_name),
                                aa_probs=21,
@@ -162,13 +140,10 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
 
         elif name == "benchmark_randall_original_naming":
             alignment_file = "{}/{}/benchmark_randall_original_naming.mafft".format(storage_folder,name)
-            tree_file = "{}/{}/RandallBenchmarkTree_OriginalNaming.tree".format(storage_folder,name)
-            build_config = BuildConfig(alignment_file=alignment_file,
-                                       use_ancestral=True, n_test=0,
-                                       build_graph=True,aa_prob=21,
-                                       triTSNE=False,leaves_testing=False,script_dir=script_dir,no_testing=False)
+            tree_file = "{}/RandallBenchmarkTree_OriginalNaming.tree".format(storage_folder)
+            build_config = BuildConfig(alignment_file=alignment_file, use_ancestral=True, n_test=0, build_graph=True,aa_prob=21,triTSNE=False,leaves_testing=False,script_dir=script_dir,no_testing=False)
             if build:
-                benchmark_randalls_dataset_train(name, storage_folder,args.one_hot_encoded,aa_prob=21)
+                benchmark_randalls_dataset_train(name, storage_folder ,aa_prob=21)
 
         elif name == "SH3_pf00018_larger_than_30aa":# Highlight: SRC Kinases, SH3 domain with PDB structures
             alignment_file = "{}/SH3_pf00018_larger_than_30aa/SH3_pf00018_larger_than_30aa.mafft".format(storage_folder) #I hope it's the correct one
@@ -190,7 +165,7 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                 pfam_dict, pdb_list = DraupnirUtils.Pfam_parser(family_name,storage_folder,first_match=True,update_pfam=False)
                 DraupnirUtils.download_PDB(pdb_list, "{}/PDB_files_Draupnir_{}_{}".format(storage_folder,family_name.strip(";"),len(pdb_list)))
                 DraupnirUtils.create_dataset(name_file=name,
-                                             one_hot_encoding=args.one_hot_encoded,
+                                             one_hot_encoding=False,
                                              method="iqtree",
                                              PDB_folder="{}/PDB_files_Draupnir_{}_{}".format(storage_folder,family_name.strip(";"),len(pdb_list)),
                                              alignment_file=alignment_file,
@@ -212,7 +187,7 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                                        script_dir=script_dir)
             if build:
                 DraupnirUtils.create_dataset(name_file=name,
-                                             one_hot_encoding=args.one_hot_encoded,
+                                             one_hot_encoding=False,
                                              method="iqtree",
                                              alignment_file=alignment_file,
                                              tree_file=tree_file,
@@ -233,7 +208,7 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                                        script_dir=script_dir)
             if build:
                 DraupnirUtils.create_dataset(name_file=name,
-                                             one_hot_encoding=args.one_hot_encoded,
+                                             one_hot_encoding=False,
                                              method="iqtree",
                                              alignment_file=alignment_file,
                                              tree_file=tree_file,
@@ -256,7 +231,7 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                 pfam_dict, pdb_list = DraupnirUtils.Pfam_parser(family_name,storage_folder,first_match=True, update_pfam=False)
                 #DraupnirUtils.download_PDB(pdb_list, "/home/lys/Dropbox/PhD/DRAUPNIR/PDB_files_Draupnir_{}_{}".format(family_name.strip(";"), len(pdb_list)))
                 DraupnirUtils.create_dataset(name_file=name,
-                                             one_hot_encoding=args.one_hot_encoded,
+                                             one_hot_encoding=False,
                                              method="iqtree",
                                              PDB_folder="{}/PDB_files_Draupnir_{}_{}".format(storage_folder,
                                                                                              family_name.strip(";"),
@@ -267,39 +242,13 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                                              rename_internal_nodes=True,
                                              min_len=30,
                                              storage_folder=storage_folder)
-        elif name == "PF00400_beta": #TODO: remove, only for fixing one hot
-            alignment_file = "{}/PF00400_beta/PF00400_beta.mafft".format(storage_folder)
-            tree_file = "{}/PF00400_beta/PF00400_beta.mafft.treefile".format(storage_folder)
-            build_config = BuildConfig(alignment_file=alignment_file,
-                                       use_ancestral=False,
-                                       n_test=0,  # Indicates the percentage of the leaves sequences for testing
-                                       build_graph=False,
-                                       aa_prob=21,
-                                       triTSNE=False,
-                                       leaves_testing=False,
-                                       script_dir=script_dir,
-                                       no_testing=True)
-            if build:
-                family_name = "PF00400;"  # protein family name
-                pfam_dict, pdb_list = DraupnirUtils.Pfam_parser(family_name, storage_folder, first_match=True,update_pfam=False)
-                # DraupnirUtils.download_PDB(pdb_list, "/home/lys/Dropbox/PhD/DRAUPNIR/PDB_files_Draupnir_{}_{}".format(family_name.strip(";"), len(pdb_list)))
-                DraupnirUtils.create_dataset(name_file=name,
-                                             one_hot_encoding=args.one_hot_encoded,
-                                             method="iqtree",
-                                             PDB_folder="/home/lys/Dropbox/PhD/DRAUPNIR_ASR/draupnir/src/draupnir/data/PDB_files_test",
-                                             alignment_file=alignment_file,
-                                             tree_file=tree_file,
-                                             pfam_dict=pfam_dict,
-                                             rename_internal_nodes=True,
-                                             min_len=30,
-                                             storage_folder=storage_folder)
         elif name == "Coral_Faviina":
             alignment_file = "{}/{}/Coral_Faviina_Aligned_Protein.fasta".format(storage_folder,name)
             tree_file = "{}/{}/c90.PP.tree".format(storage_folder,name)
             build_config = BuildConfig(alignment_file=alignment_file,use_ancestral=False,n_test=0,build_graph=False,aa_prob=21,triTSNE=False,leaves_testing=False,script_dir=script_dir,no_testing=False)
             if build:
                 DraupnirUtils.create_dataset(name_file=name,
-                                             one_hot_encoding=args.one_hot_encoded,
+                                             one_hot_encoding=False,
                                              tree_file=tree_file,
                                              alignment_file=alignment_file,
                                              aa_probs=21,
@@ -319,8 +268,7 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
             if build_config.no_testing: warnings.warn("You have chose NOT to test the Coral sequences")
             if build:
                 DraupnirUtils.create_dataset(name_file=name,
-                                             one_hot_encoding=args.one_hot_encoded,
-                                             PDB_folder=None,
+                                             one_hot_encoding=False,
                                              tree_file="{}/{}/c90.PP.tree".format(storage_folder,name),
                                              alignment_file=alignment_file,
                                              aa_probs=23,
@@ -347,34 +295,32 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
         if build:
             if fasta_file is not None and alignment_file is None:
                 alignment_file = tree_file = None
-                storage_folder = os.path.dirname(os.path.dirname(fasta_file))
+                storage_folder = os.path.dirname(fasta_file)
             else:
                 assert alignment_file is not None, "Provide at least 1 file path: alignment_file or alignment_file + tree_file"
-                storage_folder = os.path.dirname(os.path.dirname(alignment_file))
+                storage_folder = os.path.dirname(alignment_file)
 
             tree_file = DraupnirUtils.create_dataset(name_file=name,
-                                             one_hot_encoding=args.one_hot_encoded,
-                                             PDB_folder=args.pdb_folder,
+                                             one_hot_encoding=False,
                                              tree_file=tree_file,
                                              alignment_file=alignment_file,
                                              fasta_file=fasta_file,
-                                             aa_probs=args.aa_probs,
+                                             aa_probs=21,
                                              rename_internal_nodes=True,
                                              storage_folder=storage_folder)
         else:
             assert tree_file is not None, "Please provide a tree file in the same folder as the alignment or fasta sequences file, or first build the tree"
             assert alignment_file is not None, "Please provide a alignment file inside the same folder as the alignment or fasta sequences file or first build the alignment"
-            storage_folder = os.path.dirname(os.path.dirname(alignment_file))
-
-    settings_config = SettingsConfig(one_hot_encoding=args.one_hot_encoded,
+            storage_folder = os.path.dirname(alignment_file)
+    settings_config = SettingsConfig(one_hot_encoding=False,
                              model_design="GP_VAE",
                              aligned_seq=True,
-                             data_folder="{}/{}".format(storage_folder,name), #["{}".format(storage_folder) if use_custom else "{}/{}".format(storage_folder,name)][0]
+                             data_folder=["{}".format(storage_folder) if use_custom else "{}/{}".format(storage_folder,name)][0],
                              full_name=full_name,
                              tree_file=tree_file)
     return build_config,settings_config, root_sequence_name
 
-def benchmark_randalls_dataset_train(name,storage_folder,one_hot_encoded,aa_prob):
+def benchmark_randalls_dataset_train(name,storage_folder,aa_prob):
     """Processing of the leaves dataset from "An experimental phylogeny to benchmark ancestral sequence reconstruction"
     :param str name: project dataset name
     :param int aa_prob: amino acid probabilities"""
@@ -389,7 +335,7 @@ def benchmark_randalls_dataset_train(name,storage_folder,one_hot_encoded,aa_prob
                 observed_fasta.append(seq)
         SeqIO.write(observed_fasta, output_handle, "fasta")
     DraupnirUtils.create_dataset(name,
-                   one_hot_encoding=one_hot_encoded,
+                   one_hot_encoding=False,
                    fasta_file="{}/original_data/Randall_Benchmark_Observed.fasta",
                    alignment_file="{}/benchmark_randall_original.mafft".format(storage_folder),
                    tree_file="{}/RandallBenchmarkTree_OriginalNaming.tree".format(storage_folder),
